@@ -17,7 +17,15 @@
 
 """Viewer for NFO files."""
 
-__version__ = "1.19"
+__version__ = "1.21"
+
+import sys
+import warnings
+
+if hasattr(sys, "frozen"):
+    # Avoid error trying to write to non-existent stderr.
+    # http://stackoverflow.com/a/35773092
+    warnings.simplefilter("ignore")
 
 import gi
 gi.require_version("Gdk", "3.0")
